summaryrefslogtreecommitdiff
path: root/src/core/managed/Managed.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/managed/Managed.hpp')
-rw-r--r--src/core/managed/Managed.hpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/core/managed/Managed.hpp b/src/core/managed/Managed.hpp
index cc55ae0..8582702 100644
--- a/src/core/managed/Managed.hpp
+++ b/src/core/managed/Managed.hpp
@@ -19,7 +19,7 @@
#ifndef _OUSIA_MANAGED_HPP_
#define _OUSIA_MANAGED_HPP_
-#include "ManagedType.hpp"
+#include "Rtti.hpp"
#include "Manager.hpp"
namespace ousia {
@@ -108,25 +108,25 @@ public:
bool deleteData(const std::string &key);
/**
* Returns the ManagedType instance registered for instances of the type
* of this Managed instance.
*
* @return a reference to the registered ManagedType for this particular
* Managed class.
*/
- const ManagedType &type() const
+ const RttiBase &type() const
{
- return ManagedType::typeOf(*this);
+ return typeOf(*this);
}
/**
* Returns true if this Managed instance is of the given ManagedType.
*
* @param true if the ManagedType registered for this particular Managed
* class is of the given type or one of the registered parent types is of
* the given type.
*/
- bool isa(const ManagedType &t) const { return type().isa(t); }
+ bool isa(const RttiBase &t) const { return type().isa(t); }
};
/**
@@ -108,25 +108,25 @@ public:
bool deleteData(const std::string &key);
/**
- * Returns the ManagedType instance registered for instances of the type
- * of this Managed instance.
+ * Returns the RttiBase instance registered for instances of the type of
+ * this Managed instance.
*
@@ -108,25 +108,25 @@ public:
*
- * @return a reference to the registered ManagedType for this particular
+ * @return a reference to the registered RttiBase for this particular
* Managed class.
*/
@@ -108,25 +108,25 @@ public:
}
/**
- * Returns true if this Managed instance is of the given ManagedType.
+ * Returns true if this Managed instance is of the given RttiBase.
*
@@ -108,25 +108,25 @@ public:
*
- * @param true if the ManagedType registered for this particular Managed
+ * @param true if the RttiBase registered for this particular Managed
* class is of the given type or one of the registered parent types is of
* the given type.